@@ -88,6 +88,9 @@ void RequestPin::introducePin()
         "Introduce PIN"
     ));
 
+    QObject::connect(dialogWidget->pin, SIGNAL(returnPressed()),
+                     dialog, SLOT(accept()));
+
     dialog->setButtons(KDialog::Ok | KDialog::Cancel);
     dialog->setMinimumWidth(300);
     dialog->setMinimumHeight(150);
@@ -95,12 +98,10 @@ void RequestPin::introducePin()
     dialog->setMaximumHeight(150);
 
     dialogWidget->pin->setFocus(Qt::ActiveWindowFocusReason);
-
-    if (dialog->exec()) {
+    if (dialog->exec() == KDialog::Accepted) {
         cout << dialogWidget->pin->text().toLatin1().data();
         flush(cout);
         qApp->exit(0);
-        return;
     }
 
     delete dialog;
