@@ -102,9 +102,7 @@ void DiscoverPage::startScan()
     deviceList->clear();
     stopScan();
 
-    if (Manager::self()->defaultAdapter()) {
-        Manager::self()->defaultAdapter()->startDiscovery();
-    }
+    Manager::self()->defaultAdapter()->startDiscovery();
 }
 
 void DiscoverPage::stopScan()
@@ -120,6 +118,7 @@ void DiscoverPage::deviceFound(const QVariantMap &deviceInfo)
     QString name = deviceInfo["Name"].toString();
     QString icon = deviceInfo["Icon"].toString();
     QString alias = deviceInfo["Alias"].toString();
+    quint32 dClass = deviceInfo["Class"].toUInt();
 
     bool origName = false;
     if (!name.isEmpty()) {
@@ -143,6 +142,7 @@ void DiscoverPage::deviceFound(const QVariantMap &deviceInfo)
         m_itemRelation[address]->setIcon(KIcon(icon));
         m_itemRelation[address]->setData(Qt::UserRole+1, origName);
 
+        //If the device was selected but it didn't had a name, select it again
         if (deviceList->currentItem() == m_itemRelation[address]) {
             itemSelected(m_itemRelation[address]);
         }
@@ -156,8 +156,7 @@ void DiscoverPage::deviceFound(const QVariantMap &deviceInfo)
 
     m_itemRelation.insert(address, item);
 
-    //If the device has been preselected via arguments, select it
-    if (m_wizard->preselectedAddress() == address.toLower()) {
+    if (!deviceList->currentItem() &&  BlueDevil::classToType(dClass) == BLUETOOTH_TYPE_MOUSE) {
         deviceList->setCurrentItem(m_itemRelation[address]);
         itemSelected(m_itemRelation[address]);
     }
@@ -212,12 +211,6 @@ int DiscoverPage::nextId() const
     kDebug() << "From DB: " << m_wizard->agent()->isFromDatabase();
     kDebug() << "PIN: " << m_wizard->agent()->pin();
 
-    //If keyboard no matter what, we go to the keyboard page.
-    if (classToType(device->deviceClass()) == BLUETOOTH_TYPE_KEYBOARD) {
-        kDebug() << "Keyboard Pairing";
-        return BlueWizard::KeyboardPairing;
-    }
-
     //If pin ==  NULL means that not pairing is required
     if (!device->hasLegacyPairing() && !m_wizard->agent()->isFromDatabase()) {
         kDebug() << "Secure Pairing";
@@ -229,6 +222,11 @@ int DiscoverPage::nextId() const
         return BlueWizard::NoPairing;
     }
 
+    if (classToType(device->deviceClass()) == BLUETOOTH_TYPE_KEYBOARD) {
+        kDebug() << "Keyboard Pairing";
+        return BlueWizard::KeyboardPairing;
+    }
+
     if (m_wizard->agent()->isFromDatabase()) {
         return BlueWizard::LegacyPairingDatabase;
     } else {
